#!/bin/csh
#
#  sample control file to solve 4-Se MAD dataset (eIF-5A, Tom Peat's data)
#
#
setenv CCP4_OPEN UNKNOWN
setenv SYMOP /usr/local/lib/resolve/symop.lib
setenv SOLVETMPDIR /var/tmp
#
solve<<EOD > solve.log
!-----mad.script Command file to read in raw MAD data, scale, analyze and solve 
it----
title  3-wavelength MAD dataset   !  a title for this dataset
@solve.setup                   ! get our standard information read in 
logfile mad.logfile            ! write out most information to this file.
                               ! summary info will be written to "solve.prt"

checksolve			!compare solutions to the one input below

mad_atom se                    ! the anomalously scattering atom is selenium

refscattfactors                ! do not refine scattering factors (you can if
                               ! you want as long as the data is good)

readdenzo                      [ data is from scalepack. Note: for best results
                               [ use "no merge original index" in scalepack
                               [ Alternative to "readdenzo" is "readformatted"]

unmerged                       [ data have not been merged to the asymmetric unit]
                               [ Alternative to "unmerged" is "premerged"]


lambda 1                      ! info on wavelength #1 follows 
label Wavelength #  1         ! a label for this wavelength
rawmadfile p9_se_w1.sca    ! datafile for lambda 1 containing raw Intensities
 

                              ! You can have more than
                              ! one datafile per wavelength but you should put
                              ! matching I+/I- data in one datafile

                              ! All datafiles for all wavelengths
                              ! must be in the same format

wavelength 0.9790             ! wavelength value
fprimv_mad  -8.52             ! f' value at this wavelength
fprprv_mad  2.84               ! f" value at this wavelength

!				read in coordinates just to refer all the
!				solutions to the same origin as used in the pdb
!				file. (Not used to find solutions).
atomname se
xyz   0.9770      0.2439      1.1071
xyz   1.1877      0.2625      0.9833
xyz   1.1669      0.2943      0.9205
xyz   1.1142      0.1801      0.5117

lambda 2
rawmadfile p9_se_w2.sca
wavelength 0.9788
fprimv_mad  -8.0
fprprv_mad  4.0

lambda 3
rawmadfile p9_se_w4.sca
wavelength 0.9600
fprimv_mad  -3.16
fprprv_mad  3.69

nres 147                  [approx # of residues of protein in asymmetric unit]
nanomalous 3              [approx # of anomalously scattering atoms in a.u.]


SCALE_MAD                 ! read in and localscale the data
ANALYZE_MAD               ! run MADMRG and MADBST and analyze all the Pattersons
SOLVE                     ! Solve the structure

EOD
#
# Now run Resolve to do density modification
# (You can download it from http://resolve.lanl.gov 
# if you do not have it yet) 
#
resolve << EOD > resolve.log 
solvent_content 0.60        !    solvent fraction 
EOD
#
#  That's it! Now resolve.mtz has your updated phases
#
echo 'Here are your SOLVE and resolve files:' 
#
ls -l solve.prt solve.mtz solve.ezd resolve.mtz
#
echo 'All done.' 
